==> nextcloud-13.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_sharing/l10n/sk.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Shared with you" : "Vám sprístupnené",
    "Shared with others" : "Sprístupnené ostatným",
    "Shared by link" : "Sprístupnené prostredníctvom odkazu",
    "Nothing shared with you yet" : "Zatiaľ vám nikto nič nesprístupnil",
    "Files and folders others share with you will show up here" : "Tu budú zobrazené súbory a priečinky, ktoré s vami sprístupnili ostatní",
    "Nothing shared yet" : "Zatiaľ ste nič nesprístupnili",
    "Files and folders you share will show up here" : "Tu sú zobrazené súbory a priečinky, ktoré ste sprístupnili",
    "No shared links" : "Žiadne sprístupnené odkazy",
    "Files and folders you share by link will show up here" : "Tu sú zobrazené súbory a priečinky, ktoré ste sprístupnili prostredníctvom odkazov",
    "You can upload into this folder" : "Môžete nahrávať do tohto priečinka",
    "No compatible server found at {remote}" : "Nebol nájdený kompatibilný server na adrese {remote}",
    "Invalid server URL" : "Neplatná url servera",
    "Failed to add the public link to your Nextcloud" : "Pridanie verejne dostupného odkazu do vášho Nextcloud-u zlyhalo",
    "Share" : "Sprístupniť",
    "No expiration date set" : "Dátum exspirácie nenastavený",
    "Shared by" : "Sprístupňuje",
    "Sharing" : "Sprístupnenie",
    "File shares" : "Sprístupnené súbory",
    "Downloaded via public link" : "Stiahnuté prostredníctvom verejného odkazu",
    "Downloaded by {email}" : "Stiahnuté prostredníctvom {email}",
    "{file} downloaded via public link" : "{file} stiahnutý cez verejne dostupný odkaz",
    "{email} downloaded {file}" : "{email} stiahol {file}",
    "Shared with group {group}" : "Sprístupnené skupine {group}",
    "Removed share for group {group}" : "Odstránené sprístupnenie pre skupinu {group}",
    "{actor} shared with group {group}" : "{actor} sprístupnil skupine {group}",
    "{actor} removed share for group {group}" : "{actor} zrušil sprístupnenie pre skupinu {group}",
    "You shared {file} with group {group}" : "Sprístupnili ste {file} skupine {group}",
    "You removed group {group} from {file}" : "Zrušili ste sprístupnenie súboru {file} skupine {group}",
    "{actor} shared {file} with group {group}" : "{actor} sprístupnil {file} skupine {group}",
    "{actor} removed group {group} from {file}" : "{actor} zrušil sprístpnenie súboru {file} skupine {group}",
    "Shared as public link" : "Sprístupnené ako verejný odkaz",
    "Removed public link" : "Verejný odkaz odstránený",
    "Public link expired" : "Verejnému odkazu vypršala platnosť",
    "{actor} shared as public link" : "{actor} sprístupnil ako verejný odkaz",
    "{actor} removed public link" : "{actor} odstránil verejný odkaz",
    "Public link of {actor} expired" : "Verejný odkaz {actor} vypršal",
    "You shared {file} as public link" : "Sprístupnili ste súbor {file} ako verejný odkaz",
    "You removed public link for {file}" : "Odstránili ste verejný odkaz pre {file}",
    "Public link expired for {file}" : "Verejný odkaz pre {file} vypršal",
    "{actor} shared {file} as public link" : "{actor} sprístupnil {file} ako verejný odkaz",
    "{actor} removed public link for {file}" : "{actor} odstránil verejný odkaz pre {file}",
    "Public link of {actor} for {file} expired" : "Verejný odkaz používateľa {actor} pre {file} vypršal",
    "{user} accepted the remote share" : "používateľ {user} prijal vzdialené sprístupnenie",
    "{user} declined the remote share" : "používateľ {user} odmietol vzdialené sprístupnenie",
    "You received a new remote share {file} from {user}" : "Obdržali ste nové vzdialené zdieľanie súboru {file} používateľom {user}",
    "{user} accepted the remote share of {file}" : "používateľ {user} prijal vzdialené sprístupnenie súboru {file}",
    "{user} declined the remote share of {file}" : "používateľ {user} odmietol vzdialené spristupnenie súboru {file} ",
    "{user} unshared {file} from you" : "používateľ {user} vám už nesprístupňuje súbor {file}",
    "Shared with {user}" : "Zdieľané s {user}",
    "Removed share for {user}" : "Odstránené sprístupnenie pre používateľa {user}",
    "{actor} shared with {user}" : "{actor} zdieľal s {user}",
    "{actor} removed share for {user}" : "{actor} odstránil sprístupnenie pre používateľa {user}",
    "Shared by {actor}" : "Sprístupnil {actor}",
    "{actor} removed share" : "{actor} zrušil sprístupnenie",
    "You shared {file} with {user}" : "Sprístupnili ste {file} používateľovi {user}",
    "You removed {user} from {file}" : "Zrušili ste sprístupnenie {file} používateľovi {user} ",
    "{actor} shared {file} with {user}" : "{actor} sprístupnil {file} používateľovi {user}",
    "{actor} removed {user} from {file}" : "{actor} zrušil sprístupnenie {file} pre používateľa {user}",
    "{actor} shared {file} with you" : "{actor} vám sprístupnil {file}",
    "{actor} removed you from {file}" : "{actor} vám zrušil sprístupnenie {file}",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "Súbor alebo adresár zdieľaný cez email alebo verejný odkaz bol <strong>stiahnutý</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "Súbor alebo priečinok bol sprístupnený z <strong>iného servera</strong>",
    "A file or folder has been <strong>shared</strong>" : "Súbor alebo priečinok bol <strong>sprístupnený</strong>",
    "Wrong share ID, share doesn't exist" : "Neplatné ID sprístupnenia, sprístupnenie neexistuje",
    "could not delete share" : "nie je možné zmazať sprístupnenie",
    "Could not delete share" : "Nie je možné zmazať sprístupnenie",
    "Please specify a file or folder path" : "Zvoľte prosím súbor alebo cestu k priečinku",
    "Wrong path, file/folder doesn't exist" : "Neplatná cesta, súbor alebo priečinok neexistuje",
    "Could not create share" : "Nie je možné sprístupniť",
    "invalid permissions" : "neplatné oprávnenia",
    "Please specify a valid user" : "Zvoľte prosím platného používateľa",
    "Group sharing is disabled by the administrator" : "Skupinové zdieľanie je zakázané administrátorom",
    "Please specify a valid group" : "Zvoľte prosím platnú skupinu",
    "Public link sharing is disabled by the administrator" : "Sprístupnenie pomocou verejných odkazov je zakázané administrátorom",
    "Public upload disabled by the administrator" : "Verejné nahrávanie je zakázané administrátorom",
    "Public upload is only possible for publicly shared folders" : "Verejné nahrávanie je možné len do verejne sprístupnených priečinkov",
    "Invalid date, date format must be YYYY-MM-DD" : "Neplatný dátum, formát musí byť v tvare YYYY-MM-DD",
    "Sharing %s failed because the back end does not allow shares from type %s" : "Sprístupnenie %s zlyhalo, backend nepodporuje typ sprístupnenia %s",
    "You cannot share to a Circle if the app is not enabled" : "Ak aplikácia nie je povolená, nemôžete ju zdieľať s Kruhom",
    "Please specify a valid circle" : "Zadajte platný kruh",
    "Unknown share type" : "Neplatný typ sprístupnenia",
    "Not a directory" : "Nie je priečinok",
    "Could not lock path" : "Nie je možné uzamknúť cestu",
    "Wrong or no update parameter given" : "Zlý alebo žiadny zadaný parameter aktualizácie",
    "Can't change permissions for public share links" : "Nemožno zmeniť oprávnenia pre verejné sprístupnené odkazy",
    "Cannot increase permissions" : "Nie je možné navýšiť oprávnenia",
    "shared by %s" : "Sprístupnil %s",
    "Download" : "Sťahovanie",
    "Direct link" : "Priama linka",
    "Add to your Nextcloud" : "Pridať do svojho Nextcloud",
    "Share API is disabled" : "API pre sprístupňovanie je zakázané",
    "This share is password-protected" : "Táto položka je chránené heslom",
    "The password is wrong. Try again." : "Heslo je chybné. Skúste to znova.",
    "Password" : "Heslo",
    "No entries found in this folder" : "V tomto priečinku nebolo nič nájdené",
    "Name" : "Názov",
    "Share time" : "Čas sprístupnenia",
    "Expiration date" : "Dátum vypršania",
    "Sorry, this link doesn’t seem to work anymore." : "To je nepríjemné, ale tento odkaz už nie je funkčný.",
    "Reasons might be:" : "Možné dôvody:",
    "the item was removed" : "položka bola presunutá",
    "the link expired" : "linke vypršala platnosť",
    "sharing is disabled" : "sprístupňovanie je zakázané",
    "For more info, please ask the person who sent this link." : "Pre viac informácií kontaktujte osobu, ktorá vám poslala tento odkaz.",
    "Download %s" : "Stiahnuť %s",
    "Upload files to %s" : "Nahrať súbory do %s",
    "Select or drop files" : "Vyberte alebo položte súbory",
    "Uploading files…" : "Nahrávanie súborov...",
    "Uploaded files:" : "Nahrané súbory...",
    "%s is publicly shared" : "%s je verejne zdieľaný"
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");

==> nextcloud-13.0.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_sharing/l10n/sk.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Shared with others" : "Sprístupnené ostatným",
    "Shared with you" : "Vám sprístupnené",
    "Shared by link" : "Sprístupnené prostredníctvom odkazu",
    "Nothing shared with you yet" : "Zatiaľ vám nikto nič nesprístupnil",
    "Files and folders others share with you will show up here" : "Tu budú zobrazené súbory a priečinky, ktoré s vami sprístupnili ostatní",
    "Nothing shared yet" : "Zatiaľ ste nič nesprístupnili",
    "Files and folders you share will show up here" : "Tu sú zobrazené súbory a priečinky, ktoré ste sprístupnili",
    "No shared links" : "Žiadne sprístupnené odkazy",
    "Files and folders you share by link will show up here" : "Tu sú zobrazené súbory a priečinky, ktoré ste sprístupnili prostredníctvom odkazov",
    "You can upload into this folder" : "Môžete nahrávať do tohto priečinka",
    "No compatible server found at {remote}" : "Nebol nájdený kompatibilný server na adrese {remote}",
    "Invalid server URL" : "Neplatná url servera",
    "Failed to add the public link to your Nextcloud" : "Pridanie verejne dostupného odkazu do vášho Nextcloud-u zlyhalo",
    "Share" : "Sprístupniť",
    "No expiration date set" : "Dátum exspirácie nenastavený",
    "Shared by" : "Sprístupňuje",
    "Sharing" : "Sprístupnenie",
    "File shares" : "Sprístupnené súbory",
    "Downloaded via public link" : "Stiahnuté prostredníctvom verejného odkazu",
    "Downloaded by {email}" : "Stiahnuté prostredníctvom {email}",
    "{file} downloaded via public link" : "{file} stiahnutý cez verejne dostupný odkaz",
    "{email} downloaded {file}" : "{email} stiahol {file}",
    "Shared with group {group}" : "Sprístupnené skupine {group}",
    "Removed share for group {group}" : "Odstránené sprístupnenie pre skupinu {group}",
    "{actor} shared with group {group}" : "{actor} sprístupnil skupine {group}",
    "{actor} removed share for group {group}" : "{actor} zrušil sprístupnenie pre skupinu {group}",
    "You shared {file} with group {group}" : "Sprístupnili ste {file} skupine {group}",
    "You removed group {group} from {file}" : "Zrušili ste sprístupnenie súboru {file} skupine {group}",
    "{actor} shared {file} with group {group}" : "{actor} sprístupnil {file} skupine {group}",
    "{actor} removed group {group} from {file}" : "{actor} zrušil sprístpnenie súboru {file} skupine {group}",
    "Shared as public link" : "Sprístupnené ako verejný odkaz",
    "Removed public link" : "Verejný odkaz odstránený",
    "Public link expired" : "Verejnému odkazu vypršala platnosť",
    "{actor} shared as public link" : "{actor} sprístupnil ako verejný odkaz",
    "{actor} removed public link" : "{actor} odstránil verejný odkaz",
    "Public link of {actor} expired" : "Verejný odkaz {actor} vypršal",
    "You shared {file} as public link" : "Sprístupnili ste súbor {file} ako verejný odkaz",
    "You removed public link for {file}" : "Odstránili ste verejný odkaz pre {file}",
    "Public link expired for {file}" : "Verejný odkaz pre {file} vypršal",
    "{actor} shared {file} as public link" : "{actor} sprístupnil {file} ako verejný odkaz",
    "{actor} removed public link for {file}" : "{actor} odstránil verejný odkaz pre {file}",
    "Public link of {actor} for {file} expired" : "Verejný odkaz používateľa {actor} pre {file} vypršal",
    "{user} accepted the remote share" : "používateľ {user} prijal vzdialené sprístupnenie",
    "{user} declined the remote share" : "používateľ {user} odmietol vzdialené sprístupnenie",
    "You received a new remote share {file} from {user}" : "Obdržali ste nové vzdialené zdieľanie súboru {file} používateľom {user}",
    "{user} accepted the remote share of {file}" : "používateľ {user} prijal vzdialené sprístupnenie súboru {file}",
    "{user} declined the remote share of {file}" : "používateľ {user} odmietol vzdialené spristupnenie súboru {file} ",
    "{user} unshared {file} from you" : "používateľ {user} vám už nesprístupňuje súbor {file}",
    "Shared with {user}" : "Zdieľané s {user}",
    "Removed share for {user}" : "Odstránené sprístupnenie pre používateľa {user}",
    "{actor} shared with {user}" : "{actor} zdieľal s {user}",
    "{actor} removed share for {user}" : "{actor} odstránil sprístupnenie pre používateľa {user}",
    "Shared by {actor}" : "Sprístupnil {actor}",
    "{actor} removed share" : "{actor} zrušil sprístupnenie",
    "You shared {file} with {user}" : "Sprístupnili ste {file} používateľovi {user}",
    "You removed {user} from {file}" : "Zrušili ste sprístupnenie {file} používateľovi {user} ",
    "{actor} shared {file} with {user}" : "{actor} sprístupnil {file} používateľovi {user}",
    "{actor} removed {user} from {file}" : "{actor} zrušil sprístupnenie {file} pre používateľa {user}",
    "{actor} shared {file} with you" : "{actor} vám sprístupnil {file}",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "Súbor alebo adresár zdieľaný cez email alebo verejný odkaz bol <strong>stiahnutý</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "Súbor alebo priečinok bol sprístupnený z <strong>iného servera</strong>",
    "A file or folder has been <strong>shared</strong>" : "Súbor alebo priečinok bol <strong>sprístupnený</strong>",
    "Wrong share ID, share doesn't exist" : "Neplatné ID sprístupnenia, sprístupnenie neexistuje",
    "could not delete share" : "nie je možné zmazať sprístupnenie",
    "Could not delete share" : "Nie je možné zmazať sprístupnenie",
    "Please specify a file or folder path" : "Zvoľte prosím súbor alebo cestu k priečinku",
    "Wrong path, file/folder doesn't exist" : "Neplatná cesta, súbor alebo priečinok neexistuje",
    "Could not create share" : "Nie je možné sprístupniť",
    "invalid permissions" : "neplatné oprávnenia",
    "Please specify a valid user" : "Zvoľte prosím platného používateľa",
    "Group sharing is disabled by the administrator" : "Skupinové zdieľanie je zakázané administrátorom",
    "Please specify a valid group" : "Zvoľte prosím platnú skupinu",
    "Public link sharing is disabled by the administrator" : "Sprístupnenie pomocou verejných odkazov je zakázané administrátorom",
    "Public upload disabled by the administrator" : "Verejné nahrávanie je zakázané administrátorom",
    "Public upload is only possible for publicly shared folders" : "Verejné nahrávanie je možné len do verejne sprístupnených priečinkov",
    "Invalid date, date format must be YYYY-MM-DD" : "Neplatný dátum, formát musí byť v tvare YYYY-MM-DD",
    "Sharing %s failed because the back end does not allow shares from type %s" : "Sprístupnenie %s zlyhalo, backend nepodporuje typ sprístupnenia %s",
    "You cannot share to a Circle if the app is not enabled" : "Ak aplikácia nie je povolená, nemôžete ju zdieľať s Kruhom",
    "Please specify a valid circle" : "Zadajte platný kruh",
    "Unknown share type" : "Neplatný typ sprístupnenia",
    "Not a directory" : "Nie je priečinok",
    "Could not lock path" : "Nie je možné uzamknúť cestu",
    "Wrong or no update parameter given" : "Zlý alebo žiadny zadaný parameter aktualizácie",
    "Can't change permissions for public share links" : "Nemožno zmeniť oprávnenia pre verejné sprístupnené odkazy",
    "Cannot increase permissions" : "Nie je možné navýšiť oprávnenia",
    "shared by %s" : "Sprístupnil %s",
    "Download" : "Sťahovanie",
    "Direct link" : "Priama linka",
    "Add to your Nextcloud" : "Pridať do svojho Nextcloud",
    "Share API is disabled" : "API pre sprístupňovanie je zakázané",
    "No entries found in this folder" : "V tomto priečinku nebolo nič nájdené",
    "Name" : "Názov",
    "Share time" : "Čas sprístupnenia",
    "Expiration date" : "Dátum vypršania",
    "Sorry, this link doesn’t seem to work anymore." : "To je nepríjemné, ale tento odkaz už nie je funkčný.",
    "Reasons might be:" : "Možné dôvody:",
    "the item was removed" : "položka bola presunutá",
    "the link expired" : "linke vypršala platnosť",
    "sharing is disabled" : "sprístupňovanie je zakázané",
    "For more info, please ask the person who sent this link." : "Pre viac informácií kontaktujte osobu, ktorá vám poslala tento odkaz.",
    "Download %s" : "Stiahnuť %s",
    "Upload files to %s" : "Nahrať súbory do %s",
    "Select or drop files" : "Vyberte alebo položte súbory",
    "Uploading files…" : "Nahrávanie súborov...",
    "Uploaded files:" : "Nahrané súbory...",
    "{actor} removed you from {file}" : "{actor} vám zrušil sprístupnenie {file}",
    "%s is publicly shared" : "%s je verejne zdieľaný",
    "This share is password-protected" : "Táto položka je chránené heslom",
    "The password is wrong. Try again." : "Heslo je chybné. Skúste to znova.",
    "Password" : "Heslo"
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
